MethodChannelAtelerix class

An implementation of AtelerixPlatform that uses method channels.

Inheritance

Constructors

MethodChannelAtelerix()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
notificationsChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkNotificationPermissionStatus() Future<String?>
override
clearBadge() Future<void>
override
deviceToken() Future<String?>
override
getArch() Future<String?>
override
getCountryCode() Future<String?>
override
getDeviceName() Future<String?>
override
getMemorySize() Future<String?>
override
getPlatformName() Future<String?>
override
getPlatformVersion() Future<String?>
override
getTimeZone() Future<String?>
override
initializeFCM({required String senderId}) Future<void>
override
isGoogleServicesAvailable() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerDevice({required String apiKey, String? userId, String? serverUrl}) Future<void>
override
requestNotificationPermissions() Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited