Atelerix class
Main Atelerix SDK class
Provides error reporting, user management, and optional notifications.
Example:
void main() async {
WidgetsFlutterBinding.ensureInitialized();
// Initialize core SDK (errors, analytics)
Atelerix.init(
url: 'https://api.atelerix.dev',
apiKey: 'your-api-key',
projectId: 'your-project-id',
debugMode: true,
builder: () => runApp(MyApp()),
);
// Optional: Initialize notifications when needed
await Atelerix.notifications.init();
}
Constructors
- Atelerix()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- notifications → NotificationsManager
-
Access notifications features (requires explicit initialization)
final
Static Methods
-
ensureUserRegistered(
) → Future< bool> - Ensure user is registered with Atelerix
-
getUserId(
) → String? - Get current user ID
-
init(
{required String url, required String apiKey, required String projectId, required void builder(), bool? debugMode, dynamic onError(ErrorModel details)?}) → void - Initialize the Atelerix SDK
-
isUserRegistered(
) → bool - Check if user is currently registered
-
throwError(
Object error, StackTrace stack, {BugType? bugType, BugSeverity? bugSeverity, Map< String, dynamic> ? metaData}) → Future<void> - Manually report an error to Atelerix