BugType enum
Values
- runtimeError → const BugType
-
const BugType("runtime_error") - logicBug → const BugType
-
const BugType("logic_bug") - uiBug → const BugType
-
const BugType("ui_bug") - networkError → const BugType
-
const BugType("network_error") - performance → const BugType
-
const BugType("performance") - compatibility → const BugType
-
const BugType("compatibility") - validationError → const BugType
-
const BugType("validation_error") - security → const BugType
-
const BugType("security") - crash → const BugType
-
const BugType("crash") - unknown → const BugType
-
const BugType("unknown")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited