AtelerixPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- AtelerixPlatform
- Implementers
Constructors
- AtelerixPlatform()
- Constructs a AtelerixPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkNotificationPermissionStatus(
) → Future< String?> -
clearBadge(
) → Future< void> -
deviceToken(
) → Future< String?> -
getArch(
) → Future< String?> -
getCountryCode(
) → Future< String?> -
getDeviceName(
) → Future< String?> -
getMemorySize(
) → Future< String?> -
getPlatformName(
) → Future< String?> -
getPlatformVersion(
) → Future< String?> -
getTimeZone(
) → Future< String?> -
initializeFCM(
{required String senderId}) → Future< void> -
isGoogleServicesAvailable(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerDevice(
{required String apiKey, String? userId, String? serverUrl}) → Future< void> -
requestNotificationPermissions(
) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AtelerixPlatform
-
The default instance of AtelerixPlatform to use.
getter/setter pair